# Changelog

## [0.1.0] - 2025-02-12

First functional release of nanosaur CLI

### Features

- Update CLI to works with nanosaur is simulation
- swarm control
- robot configuration
- Start simulation for Gazebo and Isaac Sim
- ROS workspace control
- Docker deploy

## [0.0.1] - 2024-10-21

### Features

- First code release and publish of nanosaur cli package
